@@ -281,7 +281,7 @@ __DATA__
 <form action="<%= url_for('index') %>" method="get">
 <div class="row">
   <div class="col">
-    <select name="model" id="model" class="form-select" required>
+    <select name="model" id="model" class="form-select" onchange="this.form.submit();" required>
       <option value="">Model name...</option>
 % for my $m (@$models) {
       <option value="<%= $m %>" <%= $models && $model && lc($m) eq lc($model) ? 'selected' : '' %>><%= ucfirst $m %></option>
@@ -289,7 +289,7 @@ __DATA__
     </select>
   </div>
   <div class="col">
-    <select name="name" id="name" class="form-select">
+    <select name="name" id="name" class="form-select" onchange="this.form.submit();">
       <option value="">Setting name...</option>
 % for my $n (@$names) {
       <option value="<%= $n %>" <%= $names && $name && $n eq $name ? 'selected' : '' %>><%= ucfirst $n %></option>
@@ -297,7 +297,7 @@ __DATA__
     </select>
   </div>
   <div class="col">
-    <select name="group" id="group" class="form-select">
+    <select name="group" id="group" class="form-select" onchange="this.form.submit();">
       <option value="">Group...</option>
 % for my $g (@$groups) {
       <option value="<%= $g %>" <%= $group && $g eq $group ? 'selected' : '' %>><%= ucfirst $g %></option>
@@ -494,9 +494,12 @@ __DATA__
   </div>
 </div>
   <p></p>
-  <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Submit</button>
 % if ($id) {
+  <button type="submit" class="btn btn-primary"><i class="fa-solid fa-arrow-rotate-right"></i> Update</button>
   <a href="<%= url_for('remove')->query(id => $id, model => $model, name => $name) %>" id="remove" class="btn btn-danger" onclick="if(!confirm('Remove setting <%= $id %>?')) return false;"><i class="fa-solid fa-trash-can"></i> Remove</a>
+  <a href="<%= url_for('edit')->query(model => $model, name => $name, group => $selected->{group}) %>" id="new_setting" class="btn btn-success"><i class="fa-solid fa-plus"></i> New setting</a>
+% } else {
+  <button type="submit" class="btn btn-primary"><i class="fa-solid fa-plus"></i> Submit</button>
 % }
   <a href="<%= url_for('index')->query(model => $model, name => $name, group => $selected->{group}) %>" id="cancel" class="btn btn-warning"><i class="fa-solid fa-xmark"></i> Cancel</a>
 </form>
